@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2010-2011 thgreasi@gmail.com, jeanfi@gmail.com
+ * Copyright (C) 2010-2011 thgreasi@gmail.com
+ * Copyright (C) 2010-2012 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -64,15 +65,6 @@ static void __stdcall *adl_main_memory_alloc(int isize)
 	return lpbuffer;
 }
 
-/* Optional Memory de-allocation function */
-static void __stdcall adl_main_memory_free(void **lpbuffer)
-{
-	if (*lpbuffer) {
-		free(*lpbuffer);
-		*lpbuffer = NULL;
-	}
-}
-
 static void *getprocaddress(void *plibrary, const char * name)
 {
 	return dlsym(plibrary, name);
@@ -235,7 +227,7 @@ static int init()
 		active_amd_adapters[inumberadaptersactive-1] = iadapterindex;
 	}
 
-	adl_main_memory_free((void **) &lpadapterinfo);
+	free(lpadapterinfo);
 
 	/* Each Adapter has one GPU temperature sensor and one fan
 	   control sensor */
