@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2011 jeanfi@gmail.com
+ * Copyright (C) 2010-2012 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -80,7 +80,7 @@ static void print_version()
 		 "This is free software: you are free to change and "
 		 " redistribute it.\n"
 		 "There is NO WARRANTY, to the extent permitted by law.\n"),
-	       "2010-2011");
+	       "2010-2012");
 }
 
 static void print_help()
@@ -376,6 +376,19 @@ static gboolean initial_window_show(gpointer data)
 	return FALSE;
 }
 
+static void log_glib_info()
+{
+	log_debug("Compiled with GLib %d.%d.%d",
+		  GLIB_MAJOR_VERSION,
+		  GLIB_MINOR_VERSION,
+		  GLIB_MICRO_VERSION);
+
+	log_debug("Running with GLib %d.%d.%d",
+		  glib_major_version,
+		  glib_minor_version,
+		  glib_micro_version);
+}
+
 int main(int argc, char **argv)
 {
 	struct ui_psensor ui;
@@ -425,9 +438,17 @@ int main(int argc, char **argv)
 
 	log_init();
 
+	log_glib_info();
+#if !(GLIB_CHECK_VERSION(2, 31, 0))
+	/*
+	 * Since GLib 2.31 g_thread_init call is deprecated and not
+	 * needed.
+	 */
+	log_debug("Calling g_thread_init(NULL)");
 	g_thread_init(NULL);
+#endif
+
 	gdk_threads_init();
-	/* gdk_threads_enter(); */
 
 	gtk_init(NULL, NULL);
 
